@@ -624,6 +624,15 @@ Global airmedia getters.
 ) for qw(airmedia/config airmedia/receivers/);
 
 #RRD
+fbx_api_method rrd => (
+  description => <<'',
+Get the RRD stats.
+
+  path => 'rrd/',
+  method => 'POST',
+  params => [qw/db date_start date_end precision fields/],
+  required => [qw/db/],
+);
 
 #CALL
 fbx_api_method s'/'_'gr => (
@@ -805,15 +814,25 @@ Set the FTP config.
 );
 
 #NAT
+fbx_api_method fw_dmz => (
+  description => <<'',
+Get dmz config.
+
+  path => "fw/dmz/",
+  method => 'GET',
+  params => [ ],
+  required => [ ],
+);
+
 fbx_api_method s'/'_'gr => (
   description => <<'',
 Global NAT getters.
 
   path => $_,
   method => 'GET',
-  params => [ ],
-  required => [ ],
-) for qw(fw/dmz fw/redir/ fw/incoming/);
+  params => [ qw/suff/ ],
+  required => [ qw/suff/ ],
+) for qw(fw/redir/ fw/incoming/);
 #TODO rest
 
 #UPNP
@@ -920,7 +939,17 @@ Global Wifi getters.
   method => 'GET',
   params => [ ],
   required => [ ],
-) for qw(wifi/config wifi/ap wifi/bss wifi/planning wifi/mac_filter);
+) for qw(wifi/config wifi/planning wifi/mac_filter);
+
+fbx_api_method s'/'_'gr => (
+  description => <<'',
+Wifi AP and bss configuration.
+
+  path => $_,
+  method => 'GET',
+  params => [ qw/suff/ ],
+  required => [ qw/suff/ ],
+) for qw( wifi/ap/ wifi/bss/ );
 
 #TODO finish
 
@@ -1014,7 +1043,13 @@ WWW::FBX::Role::API::APIv3 is the freebox6 API version 3 as a Moose Role
 API documentation is given here: L<http://dev.freebox.fr/sdk/os/>
 The following methods are currently implemented in this library:
 
-=head2 call
+=head2 RRD
+
+=head3 get rrd stats
+
+ $fbx->rrd( { db => "temp", fields => [ "cpub" ], precision => 1 } );
+
+=head2 call and contacts
 
 =head3 call log
 
@@ -1358,14 +1393,22 @@ The following methods are currently implemented in this library:
 
  $fbx->fw_dmz;
 
-=head3 fw redir
+=head3 fw all redir
 
  $fbx->fw_redir;
 
-=head3 fw incoming
+=head3 fw redir
+
+ $fbx->fw_redir(0);
+
+=head3 fw all incoming
 
  $fbx->fw_incoming;
 
+=head3 fw incoming
+
+ $fbx->fw_incoming("bittorent-main");
+
 =head2 parental
 
 =head3 parental config
@@ -1498,14 +1541,38 @@ The following methods are currently implemented in this library:
 
  $fbx->wifi_config;
 
-=head3 wifi ap
+=head3 wifi ap list
 
  $fbx->wifi_ap;
 
-=head3 wifi bss
+=head3 wifi ap
+
+ $fbx->wifi_ap(0);
+
+=head3 wifi ap allowed combinations
+
+ $fbx->wifi_ap( "0/allowed_channel_comb" );
+
+=head3 wifi ap connected stations
+
+ $fbx->wifi_ap( "0/stations" );
+
+=head3 wifi ap neighbors
+
+ $fbx->wifi_ap( "0/neighbors" );
+
+=head3 wifi ap channel usage
+
+ $fbx->wifi_ap( "0/channel_usage" );
+
+=head3 wifi all bss
 
  $fbx->wifi_bss;
 
+=head3 wifi of a bss
+
+ $fbx->wifi_bss( "00:24:D4:AA:BB:CC" );
+
 =head3 wifi planning
 
  $fbx->wifi_planning;
